@@ -26,7 +26,7 @@ our %EXPORT_TAGS = ( all => \@EXPORT_OK, );
 
 our ($GSL_PREC_DOUBLE, $GSL_PREC_SINGLE, $GSL_PREC_APPROX ) = 0 .. 2;
 our $GSL_MODE_DEFAULT = $GSL_PREC_DOUBLE;
-our $VERSION = '0.42';
+our $VERSION = '0.45';
 
 =head1 NAME
 
@@ -34,7 +34,7 @@ Math::GSL - Perl interface to the GNU Scientific Library (GSL)
 
 =head1 VERSION
 
-Version 0.42
+Version 0.45
 
 =head1 SYNOPSIS
 
@@ -63,7 +63,7 @@ Each GSL subsystem has its own module. For example, the random number generator
 subsystem is Math::GSL::RNG. Many subsystems have a more Perlish and
 object-oriented frontend which can be used, as the above example shows. The raw
 GSL object is useful for using the low-level GSL functions, which in the case of
-the Matrix subsytem, would be of the form gsl_matrix_* . Each module has further
+the Matrix subsystem, would be of the form gsl_matrix_* . Each module has further
 documentation about the low-level C functions as well as using the more
 intuitive (but slightly slower) object-oriented interface.
 
@@ -208,7 +208,7 @@ common problem that happens on RedHat Linux (RHEL) and CentOS looks like this:
     cannot restore segment prot after reloc: Permission denied at /usr/lib/perl5/5.10.0/i386-linux-thread-multi/DynaLoader.pm line 203.
     #  at blib/lib/Math/GSL/Errno.pm line 10
 
-This is due the the SE Linux setting being set to "enforcing". To Temporarily
+This is due to the SE Linux setting being set to "enforcing". To Temporarily
 disable enforcement on a running system:
 
     /usr/sbin/setenforce 0
@@ -263,7 +263,7 @@ This Perl module is dedicated in memory of Nick Ing-Simmons.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008-2016 Jonathan "Duke" Leto, Thierry Moisan all rights reserved.
+Copyright (C) 2008-2024 Jonathan "Duke" Leto, Thierry Moisan all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
